# chrpa
Climate Hazards Return Period Analysis


chrpa contains a series of functions to support climate hazard analyses. The functions facilitate analyses to understand how return periods and exceedance probability for straight-line wind and precipidation at key locations change under future climate conditions predicted by climate models.  The package also contains example datasets and tutorials to help demonstrate how the functions can be used.

Installation
=============
pvops can be installed using `pip`. See more information at [readthedocs](https://chrpa.readthedocs.io/en/latest/).


Package Layout and Documentation
==============

The package is delineated into the following directories. Refer to the `examples` directory for a full run-through of the available functionality.
```

├───chrpa
│   ├───main
│   │ 
│   ├───tests
│      
│   
├───docs
│   
└───example
```

More information about these modules is available at [readthedocs](https://chrpa.readthedocs.io/en/latest/).

Citing
======

If using this package, please cite [our paper](https://chrpa.readthedocs.io/en/latest/) using the following:


Contributing
============

The long-term success of chrpa requires community support. Please see the [Contributing page](https://pvops.readthedocs.io/en/latest/) for more on how you can contribute.


Copyright and License
=======

chrpa is copyrighted through Sandia National Laboratories. The software is distributed under the Revised BSD License. See [copyright and license](https://github.com/hmendo/chrpa/blob/main/LICENSE) for more information.
